<?php
/**
 * @class 		Admin_Settings_Tab_Billing
 */

if ( ! defined( 'ABSPATH' ) ) exit;


class Admin_Settings_Tab_Billing extends Admin_Settings_Tab_Abstract {

	/** @var string */
	public $prefix = 'chatxai_';

	public $accountStuses = [
		'active' => ['label' => 'Active', 'type' => 'success'],
		'inactive' => ['label' => 'Disabled', 'type' => 'danger'],
		'paymenterror' => ['label' => 'Payment error', 'type' => 'warning'],
		'banned' => ['label' => 'Banned', 'type' => 'danger'],
		'disabled' => ['label' => 'Permanently disabled', 'type' => 'danger']
	];


	function __construct() {
		$this->id = 'billing';
		$this->name = __( 'Billing', 'chatx-ai' );
		$this->hide_submit = true;
	}

	function load_settings() {

		if ( ! empty( $this->settings ) )
			return;

		$payments_data = $this->get_payments_data();
		$account_status = Chatx_Ai_Options::read('chatxai_account_status');

		$this->section_start(
			'chatxai_billing',
			'',
			__( 'For security reasons if you want to update the payment method used, you need to go to your account on ChatX.ai. ', 'chatx-ai' )
		);

		if($payments_data && $payments_data->methods_url){
			$this->add_setting( 'account_status', [
				'type' => 'custom',
				'title' => 'Payment Method',
				'html' => '<a class="button button-primary" target="_blank" href="' . $payments_data->methods_url . '">' . __( 'Edit', 'chatx-ai' ) . '</a>'
			]);
		}

		if(in_array($account_status, ['active', 'inactive'])){
			if($account_status == "inactive"){
				$this->add_setting( 'account_status', [
					'type' => 'custom',
					'title' => 'Activate your account',
					'html' => '<button class="button button-primary button-chatx-as" data-setting="activate">' . __( 'Activate', 'chatx-ai' ) . '</button>'
				]);
			}
			else{
				$this->add_setting( 'account_status', [
					'type' => 'custom',
					'title' => 'Deactivate my account',
					'html' => '<button class="button button-danger button-chatx-as" data-setting="deactivate">' . __( 'Deactivate', 'chatx-ai' ) . '</button>'
				]);
			}
		}
		else{
			if(isset($this->accountStuses[$account_status])){
				$accs = $this->accountStuses[$account_status];
				$this->add_setting( 'account_status', [
					'type' => 'custom',
					'title' => 'Account status',
					'html' => '<label class="text-' . $accs['type'] . '"> ' . $accs['label'] . '</label>'
				]);
			}
		}

		$this->section_end( 'chatxai_billing' );

		// Details section
		$this->section_start( 'billing_details_section', __( 'Company Details', 'chatx-ai' ) );

		$this->add_setting( 'billing_company', [
			'type' => 'text',
			'title' => __( 'Company Name', 'chatx-ai' )
		]);

		$this->add_setting( 'billing_details', [
			'type' => 'textarea',
			'title' => __( 'Other Details', 'chatx-ai' ),
			'desc' => __( 'eg: Company Tax ID, Address, etc. Don\'t add phone number, email or website address because these will be automatically added in the invoice.', 'chatx-ai' )
		]);

		$this->section_end( 'billing_details_section' );

		// Show submit button after billing details
		$this->add_setting( 'billing_details_submit', [
			'type' => 'submit',
			'title' => __( 'Save details', 'chatx-ai' )
		]);

		// Payments section
		$this->section_start( 'payments_section', __( 'Invoices', 'chatx-ai' ) );

		$this->add_setting( 'payments_table', [
			'type' => 'view',
			'view' => 'payments-table.php',
			'data' => [
				'invoicesAccessKey' =>  Chatx_Ai_Options::read('chatxai_api_key'),
				'payments_data' => $payments_data
			]
		]);

		$this->section_end( 'payments_section' );
	}


	/**
	 * @return Payment Method Editor URL
	 */
	function get_payments_data(){
	    $url = CHATX_BAESURL . '/plugin/payments/data';

	    $data = [
	        "at" => Chatx_Ai_Options::read('chatxai_api_token'),
	        "ak" => Chatx_Ai_Options::read('chatxai_api_key'),
	        "currency" => get_woocommerce_currency()
	    ];

	    $options = array(
	        'http' => array(
	            'header'  => "Content-type: application/x-www-form-urlencoded\r\n",
	            'method'  => 'POST',
	            'content' => http_build_query($data, true)
	        )
	    );

	    $result = null;

	    try {
	        $context  = stream_context_create($options);
	        $result = file_get_contents($url, false, $context);
	    } catch (Exception $e) {
	        echo $e->getMessage();
	    }

	    if($result){
	        $rdata = json_decode($result);
	        if($rdata->success){
	            return $rdata;
	        }
	    }

	    return null;
	}


	/**
	 * @return array
	 */
	function get_settings() {
		$this->load_settings();
		return $this->settings;
	}

}

return new Admin_Settings_Tab_Billing();
