<?php
/**
 * @class 		Admin_Settings_Tab_Chatbot
 */

if ( ! defined( 'ABSPATH' ) ) exit;


class Admin_Settings_Tab_Chatbot extends Admin_Settings_Tab_Abstract {

	/** @var string */
	public $prefix = 'chatxai_';


	function __construct() {
		$this->id = 'chatbot';
		$this->name = __( 'Chatbot', 'chatx-ai' );
		$this->show_tab_title = false;
	}


	function load_settings() {

		if ( ! empty( $this->settings ) )
			return;

		$this->section_start( 'chatxai_chatbot' );

		$this->add_setting( 'section_title_1', [
			'type' => 'title',
			'title' => __( 'Chatbot Options', 'chatx-ai' )
		]);

		$this->add_setting( 'chatbot_enable_discount', [
			'type' => 'checkbox',
			'title' => __( 'Enable Discounts', 'chatx-ai' ),
			'autoload' => true,
			'desc' => __( 'Allow the chatbot to offer discounts to customers, to have more chances to recover a cart.', 'chatx-ai' )
		]);

		$this->add_setting( 'chatbot_discount_max_percent', [
			'type' => 'number',
			'title' => __( 'Maximum Discount %', 'chatx-ai' ),
			'custom_attributes' => [
				'min' => 0,
				'max' => 100,
				'step' => 0.01
			],
			'autoload' => true,
			'desc' => __( 'The maximum discount percent that the chatbot can use. It will not offer the same discount every time, so that we don\'t create a habbit.', 'chatx-ai' )
		]);

		$this->add_setting( 'chatbot_enable_scarcity', [
			'type' => 'checkbox',
			'title' => __( 'Enable Scarcity', 'chatx-ai' ),
			'autoload' => true,
			'desc' => __( 'Allow the chatbot to use scarcity to persuade the customer to hurry with the decision of recovering an abandoned cart.', 'chatx-ai' )
		]);

		$this->section_end( 'chatxai_chatbot' );
	}


	/**
	 * @return array
	 */
	function get_settings() {
		$this->load_settings();
		return $this->settings;
	}

}

return new Admin_Settings_Tab_Chatbot();
