<?php
/**
 * @class 		Admin_Settings_Tab_General
 */

if ( ! defined( 'ABSPATH' ) ) exit;


class Admin_Settings_Tab_General extends Admin_Settings_Tab_Abstract {

	/** @var string */
	public $prefix = 'chatxai_';


	function __construct() {
		$this->id = 'general';
		$this->name = __( 'General', 'chatx-ai' );
	}


	function load_settings() {

		if ( ! empty( $this->settings ) )
			return;

		$this->section_start( 'chatxai_general' );

		$this->add_setting( 'enable_carts_tracking', [
			'type' => 'checkbox',
			'title' => __( 'Enable Abandoned Cart Tracking', 'chatx-ai' ),
			'autoload' => true,
			'desc' => __( 'If activated, we will track the abandoned carts from the chatbot\'s subscribers and try to recover them on Messenger.', 'chatx-ai' )
		]);

		$this->add_setting( 'send_time', [
			'type' => 'number',
			'title' => __( 'Carts Send Time', 'chatx-ai' ),
			'desc' => __( 'In how many hours to contact the customer via Messenger regarding the abandoned cart?', 'chatx-ai' ),
			'default'       => 6,
		]);

		$this->add_setting( 'enable_add_to_cart_tracking', [
			'type' => 'checkbox',
			'title' => __( 'Enable Add to Cart Tracking', 'chatx-ai' ),
			'autoload' => true,
			'desc' => __( 'If activated, "Send to Messenger" checkbox will appear near every "Add to cart" button. Any person who adds a product in the cart will be a subscriber of your chatbot.', 'chatx-ai' )
		]);

		$this->add_setting( 'enable_add_to_cart_archive_tracking', [
			'type' => 'checkbox',
			'title' => __( 'Enable Add to Cart Archive Tracking', 'chatx-ai' ),
			'autoload' => true,
			'desc' => __( 'If activated, "Send to Messenger" checkbox will appear at the bottom of any products page. A person who adds a product in the cart will be a subscriber of your chatbot.', 'chatx-ai' )
		]);

		$this->add_setting( 'login_checkbox_enable', [
			'type' => 'checkbox',
			'title' => __( 'Enable Login Customer Matching', 'chatx-ai' ),
			'autoload' => true,
			'desc' => __( 'If activated, a "Send to Messenger" checkbox will appear near the login form of your website. Every person who login will be a subscriber of your chatbot.', 'chatx-ai' )
		]);

		$this->add_setting( 'register_checkbox_enable', [
			'type' => 'checkbox',
			'title' => __( 'Enable Register Customer Matching', 'chatx-ai' ),
			'autoload' => true,
			'desc' => __( 'If activated, a "Send to Messenger" checkbox will appear near the register form of your website. Every person who register will be a subscriber of your chatbot.', 'chatx-ai' )
		]);

		$this->section_end( 'chatxai_general' );
	}


	/**
	 * @return array
	 */
	function get_settings() {
		$this->load_settings();
		return $this->settings;
	}

}

return new Admin_Settings_Tab_General();
