<?php

namespace CXModule\AbandonedCarts;

use WordPress\ORM\RestoredCart;

if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * @class Admin_Controller_Carts
 * @since 2.7.7
 */
class Admin_Controller_RestoredCarts extends Admin_Controller_Abstract {

	/** @var string  */
	protected static $nonce_action = 'carts-action';


	static function output() {

		$action = self::get_current_action();

		switch ( $action ) {
			case 'bulk_delete':
				self::action_bulk_edit( str_replace( 'bulk_', '', $action ) );
				self::output_list_table();
				break;

			default:
				self::output_list_table();
				break;
		}
	}

	private static function output_list_table() {

		require_once(__DIR__ . '/../report-list-table.php');
		require_once(__DIR__ . '/../reports/restored-carts.php');

		$table = new Report_RestoredCarts();
		$table->prepare_items();
		$table->nonce_action = self::$nonce_action;


		$totalRestoredCarts =  RestoredCart::all();
		$totalRestoredAndOrderedCarts = 0;
		$totalRestoredAndOrderedCartsRevenue = 0;
		$totalRestoredRevenue = 0;

		foreach ($totalRestoredCarts as $restoredCart) {
			$totalRestoredRevenue += $restoredCart->total;
			if($restoredCart->order_id){
				$totalRestoredAndOrderedCarts += 1;
				$totalRestoredAndOrderedCartsRevenue += $restoredCart->total;
			}
		}

		$sidebar_content = '<p>' .
			__( 'The carts below are all the carts which were successfully recovered by ChatX. On these carts totals we calculate the percentage you will have to pay each month.', 'chatx-ai' )
			. '</p>';

		Admin::get_view( 'page-table-with-sidebar', [
			'page' => 'carts',
			'table' => $table,
			'heading' => __( 'Recovered Carts', 'chatx-ai' ),
			'sidebar_content' => $sidebar_content,
			'messages' => self::get_messages()
		]);
	}

	/**
	 * @param $action
	 */
	private static function action_bulk_edit( $action ) {

		self::verify_nonce_action();

		$ids = CXClean::ids( cx_request( 'cart_ids' ) );

		if ( empty( $ids ) ) {
			self::$errors[] = __( 'Please select some carts to bulk edit.', 'chatx-ai');
			return;
		}

		foreach ( $ids as $id ) {

			$cart =  RestoredCart::find_one_by('id', $id);

			if ( ! $cart )
				continue;

			switch ( $action ) {
				case 'delete':
					$cart->delete();
					break;
			}
		}

		self::$messages[] = __( 'Bulk edit completed.', 'chatx-ai' );
	}
}
