<?php

if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

/**
 * CXAC_Report_List_Table
 *
 * @since 2.0
 */
class CXAC_Report_List_Table extends WP_List_Table {

	public $show_tablenav_at_top = false;

	public $nonce_action = 'chatxai_report_action';

	/** @var bool */
	public $enable_search = false;

	/** @var string  */
	public $search_input_id = 'chatxai_search_table';

	/** @var string */
	public $search_button_text;

	/** @var string */
	protected $default_param_orderby = '';

	/** @var string */
	protected $default_param_order = 'DESC';


	/**
	 * @param array|string $args
	 */
	function __construct( $args ) {
		parent::__construct( $args );
	}


	/**
	 * Output the report
	 */
	function output_report() {
		$this->prepare_items();
		echo '<div id="poststuff" class="woocommerce-reports-wide">';
		$this->display();
		echo '</div>';
	}

	/**
	 *
	 */
	function display_tablenav( $position ) {
		if ( $position != 'top' || $this->show_tablenav_at_top ) {
			parent::display_tablenav( $position );
		}
	}


	/**
	 * @param $email
	 * @return string
	 */
	function format_email( $email ) {
		$email = esc_attr( $email );
		return '<a href="mailto:'.$email.'">'.$email.'</a>';
	}


	/**
	 * @param WP_User $user
	 * @return string
	 */
	function format_user( $user ) {
		if ( $user ) {
			$name = esc_attr( sprintf( _x( '%1$s %2$s', 'full name', 'chatxai' ), $user->first_name, $user->last_name ) );
			$email = esc_attr( $user->user_email );
			return "$name <span class=\"text-muted\">$email</span> ";
		}
		else {
			$this->format_blank();
		}
	}


	/**
	 * @param $email
	 */
	function format_guest( $guest ) {
		if ( $guest->email ) {
			$email = esc_attr( $guest->email );
			echo esc_attr( __( 'Guest Email -> ', 'chatxai' ) ) . ' <a href="mailto:'.$email.'">'.$email.'</a>';
		} else {
			echo esc_attr( __( 'Guest ID -> ', 'chatxai' ) ) . ' ' . $guest->primary_key();
		}
	}


	/**
	 * @return array
	 */
	protected function get_table_classes() {
		return [ 'chatxai-list-table', 'widefat', 'fixed', 'striped', $this->_args['plural'] ];
	}


	/**
	 * @param $date
	 * @param bool $is_gmt
	 * @return string
	 */
	function format_date( $date, $is_gmt = true ) {

		$output = '';

		if ( $date instanceof DateTime ) {
			$date = $date->getTimestamp();
		}

		if ( $date ) {
			$output = cx_display_time( $date, false, $is_gmt );
		}

		return $output ? $output : $this->format_blank();
	}

	function format_blank() {
		echo '-';
	}

}
