<?php

if ( ! defined( 'ABSPATH' ) ) exit;

use WordPress\ORM\Guest;

/**
 * @class CXAC_Report_Guests
 * @since 2.4.9
 */
class CXAC_Report_Guests extends CXAC_Report_List_Table {

	public $_column_headers;

	public $max_items;


	function __construct() {
		parent::__construct([
			'singular' => __( 'Guest', 'chatxai' ),
			'plural' => __( 'Guests', 'chatxai' ),
			'ajax' => false
		]);
	}


	function no_items() {
		_e( 'No active guests found.', 'chatxai' );
	}


	/**
	 * get_columns function.
	 */
	function get_columns() {
		$columns = [
			'cb' => '<input type="checkbox" />',
			'id' => __( 'Guest', 'chatxai' ),
			'email' => __( 'Email', 'chatxai' ),
			'last_active' => __( 'Last Active', 'chatxai' ),
			'created' => __( 'Created', 'chatxai' ),
			'ip' => __( 'IP', 'chatxai' )
		];

		return $columns;
	}

	/**
	 * prepare_items function.
	 */
	function prepare_items() {

		$this->_column_headers = [ $this->get_columns(), [], $this->get_sortable_columns() ];
		$current_page = absint( $this->get_pagenum() );
		$per_page = apply_filters( 'chatxai_report_items_per_page', 20 );

		$this->get_items( $current_page, $per_page );

		$this->set_pagination_args([
			'total_items' => $this->max_items,
			'per_page'    => $per_page,
			'total_pages' => ceil( $this->max_items / $per_page )
		]);
	}

	/**
	 *
	 */
	function get_items( $current_page, $per_page ) {

		$query = Guest::query();
		$query->limit( $per_page );
		$query->offset( ($current_page - 1 ) * $per_page );
		$query->order('DESC');
		$res = $query->find();

		$this->items = $res;

		$this->max_items = $query->found_rows;
	}

	/**
	 * @param $guest ChatXAC\Guest
	 * @return string
	 */
	function column_cb( $guest ) {
		return '<input type="checkbox" name="guest_ids[]" value="' . absint( $guest->get_id() ) . '" />';
	}

	/**
	 * @param ChatXAC\Guest $guest
	 * @return string
	 */
	function column_id( $guest ) {
		return '#' . $guest->get_id();
	}


	/**
	 * @param ChatXAC\Guest $guest
	 * @return string
	 */
	function column_email( $guest ) {
		return "<a href='mailto:{$guest->get_email()}'>{$guest->get_email()}</a>";
	}

	/**
	 * @param ChatXAC\Guest $guest
	 * @return string
	 */
	function column_ip( $guest ) {
		if ( $guest->ip ) {
			return esc_attr( $guest->ip );
		}
		$this->format_blank();
	}

	/**
	 * @param ChatXAC\Guest $guest
	 * @return false|string
	 */
	function column_created( $guest ) {
		return cx_display_time( $guest->created );
	}


	/**
	 * @param ChatXAC\Guest $guest
	 * @return string
	 */
	function column_last_active( $guest ) {
		return cx_display_time( $guest->last_active );
	}

	/**
	 * Retrieve the bulk actions
	 */
	function get_bulk_actions() {
		$actions = [
			'bulk_delete' => __( 'Delete', 'chatxai' ),
		];

		return $actions;
	}

}
