<?php

namespace CXModule\AbandonedCarts;

use WordPress\ORM\RestoredCart;

if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * @class Report_Carts
 * @since 2.0
 */
class Report_RestoredCarts extends \CXAC_Report_List_Table {

	public $_column_headers;
	public $max_items;


	function __construct() {
		parent::__construct([
			'singular' => __( 'Restored Cart', 'chatxai' ),
			'plural' => __( 'Restored Carts', 'chatxai' ),
			'ajax' => false
		]);
	}


	function no_items() {
		_e( 'No carts found.', 'chatxai' );
	}


	/**
	 * @param Cart $cart
	 * @param mixed $column_name
	 */
	function column_default( $cart, $column_name ) {

		if ( $cart->get_user_id() ) {
			$user = get_user_by( 'id', $cart->get_user_id() );
		}
		else {
			$guest = $cart->get_guest();
		}

		switch( $column_name ) {

			case 'id':
				echo '#' . $cart->get_id();
				break;

			case 'user':

				if ( ! $cart->get_user_id() && $guest ) {
					$this->format_guest( $guest );
				}
				elseif ( $cart->get_user_id() ) {
					return $this->format_user( $user );
				}
				else {
					$this->format_blank();
				}
				break;

			case 'last_modified':
				return $this->format_date( $cart->last_modified );
				break;

			case 'items':
				echo count( $cart->get_items() );
				break;

			case 'total':
				echo wc_price( $cart->get_total() );
				break;

			case 'orderid':
				echo '<a href="'.get_admin_url(null, 'post.php?post=' . $cart->order_id . '&action=edit').'">' . $cart->order_id . '</a>';
				break;


			case 'actions':
			 	$url = add_query_arg([
			 		'action' => 'cx_modal_cart_info',
			 		'cart_id' => $cart->get_id(),
			 		'cart_type' => 'restored'
			 	], admin_url( 'admin-ajax.php' ) );

			 	echo '<a class="button view aw-button-icon" data-chatxai-modal-type="ajax" data-chatxai-modal-title="'. sprintf(__( "Restored Cart #%s", 'chatxai' ), $cart->get_id() ) .'" href="' . $url . '">View</a>';

			 	break;
		}
	}


	/**
	 * @param $cart Cart
	 * @return string
	 */
	function column_cb( $cart ) {
		return '<input type="checkbox" name="cart_ids[]" value="' . absint( $cart->get_id() ) . '" />';
	}


	/**
	 * get_columns function.
	 */
	function get_columns() {

		$columns = [
			'cb' => '<input type="checkbox" />',
			'id' => __( 'Cart', 'chatxai' ),
			'user' => __( 'Customer', 'chatxai' ),
			'last_modified' => __( 'Last Updated', 'chatxai' ),
			'items' => __( 'Items', 'chatxai' ),
			'total' => __( 'Total', 'chatxai' ),
			'orderid' => __( 'Order', 'chatxai' ),
			'actions' => '',
		];

		return $columns;
	}

	/**
	 * prepare_items function.
	 */
	function prepare_items() {

		$this->_column_headers = [ $this->get_columns(), [], $this->get_sortable_columns() ];
		$current_page = absint( $this->get_pagenum() );
		$per_page = apply_filters( 'chatxai_report_items_per_page', 20 );

		$this->get_items( $current_page, $per_page );

		/**
		 * Pagination
		 */
		$this->set_pagination_args([
			'total_items' => $this->max_items,
			'per_page'    => $per_page,
			'total_pages' => ceil( $this->max_items / $per_page )
		]);
	}



	/**
	 * Get Products matching stock criteria
	 */
	function get_items( $current_page, $per_page ) {
		$query = RestoredCart::query();
		$query->limit( $per_page );
		$query->offset( ($current_page - 1 ) * $per_page );
		$query->sort_by('last_modified');
		$query->order('DESC');
		$res = $query->find();

		$this->items = $res;

		$count = RestoredCart::query()->find(true);
		$this->max_items = $count ? $count : 0;
	}


	/**
	 * Retrieve the bulk actions
	 */
	function get_bulk_actions() {
		$actions = [
			'bulk_delete' => __( 'Delete', 'chatxai' )
		];

		return $actions;
	}

}
