<?php

namespace WordPress\ORM;

class RestoredCart extends BaseModel
{
    public $id;
    public $user_id;
    public $guest_id;
    public $order_id;
    public $last_modified;
    public $created;
    public $items;
    public $coupons;
    public $total;
    public $token;

    public static function get_primary_key()
    {
        return 'id';
    }

    public static function get_table()
    {
        global $wpdb;
        return $wpdb->prefix . 'chatx_restored_carts';
    }

    public static function get_searchable_fields()
    {
        return [];
    }

    public static function create_table() {
        global $wpdb;
        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

        $charset_collate = $wpdb->get_charset_collate();
        $tablename = $wpdb->prefix . 'chatx_restored_carts';

        dbDelta("CREATE TABLE IF NOT EXISTS {$tablename} (
            id bigint(20) NOT NULL AUTO_INCREMENT,
            user_id bigint(20) DEFAULT NULL,
            guest_id bigint(20) DEFAULT NULL,
            order_id bigint(20) DEFAULT NULL,
            last_modified datetime DEFAULT NULL,
            created datetime DEFAULT NULL,
            items longtext NOT NULL,
            coupons longtext NOT NULL,
            total varchar(32) NOT NULL DEFAULT '0',
            token varchar(32) NOT NULL DEFAULT '',
            PRIMARY KEY  (id)
            ) {$charset_collate};");
    }

    function setToken( $token = false ) {
        if ( ! $token ) {
            $token = cx_generate_key( 32 );
        }
        $this->token = $token;
    }

    function setLastModified($date){
        $this->last_modified = $date->format('Y-m-d H:i:s');
    }

    function setCreated($date){
        $this->created = $date->format('Y-m-d H:i:s');
    }

    function getApiFormat(){
        $cart = $this->to_array();
        $cart['currency'] = get_woocommerce_currency();

        $items = $this->items;
        $cart['items'] = [];

        foreach ($items as $item) {
            $product = wc_get_product( $item['product_id'] );

            if ($product) {
                $image = wp_get_attachment_image_src(get_post_thumbnail_id($item['product_id']), 'full');
                $item['id'] = $item['product_id'];
                $item['name']  = $product->get_title();
                $item['url']   = get_permalink($item['product_id']);
                $item['image'] = is_array($image) ? $image[0] : null;
                unset($item['product_id']);
            }

            $cart['items'][] = $item;
        }

        return $cart;
    }

    public function sync(){
        $this->setLastModified(new \DateTime());
        $this->items = WC()->cart->get_cart_for_session();

        $coupon_data = [];

        foreach( WC()->cart->get_applied_coupons() as $coupon_code ) {
            $coupon_data[$coupon_code] = [
                'discount_incl_tax' => WC()->cart->get_coupon_discount_amount( $coupon_code, false ),
                'discount_excl_tax' => WC()->cart->get_coupon_discount_amount( $coupon_code ),
                'discount_tax' => WC()->cart->get_coupon_discount_tax_amount( $coupon_code )
            ];
        }

        $this->coupons = $coupon_data;

        if ( get_option( 'woocommerce_tax_display_cart' ) === 'excl' ) {
            $this->total = WC()->cart->cart_contents_total;
        }
        else {
            $this->total = WC()->cart->cart_contents_total + WC()->cart->tax_total;
        }

        $this->save();
    }

    public function get_guest(){
        return Guest::find_one_by('id', $this->guest_id);
    }
}
