<?php

namespace CXLibrary;

/**
 * @class CXOrder
 * @since 2.9
 */
class CXOrder {


	/**
	 * @param \WC_CXOrder $order
	 * @return int
	 */
	static function get_id( $order ) {
		return is_callable( [ $order, 'get_id' ] ) ? $order->get_id() : $order->id;
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_date_created( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return $order->order_date;
		}
		else {
			return $order->get_date_created();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_customer_ip( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return $order->customer_ip_address;
		}
		else {
			return $order->get_customer_ip_address();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @param $key
	 * @return mixed
	 */
	static function get_meta( $order, $key ) {
		if ( is_callable( [ $order, 'get_meta' ] ) ) {
			return $order->get_meta( $key );
		}
		else {
			return get_post_meta( $order->id, $key, true );
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @param $key
	 * @param $value
	 * @return mixed
	 */
	static function update_meta( $order, $key, $value ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			update_post_meta( $order->id, $key, $value );
		}
		else {
			$order->update_meta_data( $key, $value );
			$order->save();
		}
	}

	/**
	 * @param \WC_CXOrder $order
	 * @param $key
	 * @return mixed
	 */
	static function delete_meta( $order, $key ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			delete_post_meta( $order->id, $key );
		}
		else {
			$order->delete_meta_data( $key );
			$order->save();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @param $value
	 */
	static function set_customer_id( $order, $value ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			update_post_meta( $order->id, '_customer_user', $value );
		}
		else {
			$order->set_customer_id( $value );
			$order->save();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @param $value
	 */
	static function set_billing_email( $order, $value ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			update_post_meta( $order->id, '_billing_email', $value );
		}
		else {
			$order->set_billing_email( $value );
			$order->save();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_email( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_email', true );
		}
		else {
			return $order->get_billing_email();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_first_name( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_first_name', true );
		}
		else {
			return $order->get_billing_first_name();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_last_name( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_last_name', true );
		}
		else {
			return $order->get_billing_last_name();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_company( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_company', true );
		}
		else {
			return $order->get_billing_company();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_phone( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_phone', true );
		}
		else {
			return $order->get_billing_phone();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_country( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_country', true );
		}
		else {
			return $order->get_billing_country();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_address_1( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_address_1', true );
		}
		else {
			return $order->get_billing_address_1();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_address_2( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_address_2', true );
		}
		else {
			return $order->get_billing_address_2();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_city( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_city', true );
		}
		else {
			return $order->get_billing_city();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_state( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_state', true );
		}
		else {
			return $order->get_billing_state();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_billing_postcode( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_billing_postcode', true );
		}
		else {
			return $order->get_billing_postcode();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_shipping_country( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_shipping_country', true );
		}
		else {
			return $order->get_shipping_country();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_shipping_address_1( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_shipping_address_1', true );
		}
		else {
			return $order->get_shipping_address_1();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_shipping_address_2( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_shipping_address_2', true );
		}
		else {
			return $order->get_shipping_address_2();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_shipping_city( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_shipping_city', true );
		}
		else {
			return $order->get_shipping_city();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_shipping_state( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_shipping_state', true );
		}
		else {
			return $order->get_shipping_state();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_shipping_postcode( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return get_post_meta( $order->id, '_shipping_postcode', true );
		}
		else {
			return $order->get_shipping_postcode();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @param \WC_CXOrder_Item_Product|array $item
	 * @return \WC_Product
	 */
	static function get_product_from_item( $order, $item ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return $order->get_product_from_item( $item );
		}
		else {
			return $item->get_product();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_order_key( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return $order->order_key;
		}
		else {
			return $order->get_order_key();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @param $note
	 */
	static function set_customer_note( $order, $note ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			wp_update_post([
				'ID' => $order->id,
				'post_excerpt' => $note
			]);
		}
		else {
			$order->set_customer_note( $note );
			$order->save();
		}
	}


	/**
	 * @param \WC_CXOrder $order
	 * @return string
	 */
	static function get_customer_note( $order ) {
		if ( version_compare( WC()->version, '2.7', '<' ) ) {
			return $order->customer_note;
		}
		else {
			return $order->get_customer_note();
		}
	}


}
