<?php
/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Chatx_Ai
 * @subpackage Chatx_Ai/public
 * @author     Chatx.ai <contact@chatx.ai>
 */
class Chatx_Ai_Public
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {

        $this->plugin_name = $plugin_name;
        $this->version     = $version;

        $this->chatxai_options['mess_app_id'] = Chatx_Ai_Options::read('chatxai_messenger_app_id');
        $this->chatxai_options['page_id']     = Chatx_Ai_Options::read('chatxai_fb_page_id');
        $this->chatxai_options['origin']      = Chatx_Ai_Options::read('chatxai_origin');

        $this->api_token = Chatx_Ai_Options::read('chatxai_api_token');
        $this->api_key   = Chatx_Ai_Options::read('chatxai_api_key');

        $this->enable_carts_traking              = Chatx_Ai_Options::read('chatxai_enable_carts_tracking') == "yes";
        $this->login_checkbox_enable             = Chatx_Ai_Options::read('chatxai_login_checkbox_enable') == "yes";
        $this->register_checkbox_enable          = Chatx_Ai_Options::read('chatxai_register_checkbox_enable') == "yes";
        $this->addtocart_checkbox_enable         = Chatx_Ai_Options::read('chatxai_enable_add_to_cart_tracking') == "yes";
        $this->addtocart_archive_checkbox_enable = Chatx_Ai_Options::read('chatxai_enable_add_to_cart_archive_tracking') == "yes";

    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Chatx_Ai_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Chatx_Ai_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/chatx-ai-public.css', array(), $this->version, 'all');

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Chatx_Ai_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Chatx_Ai_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/chatx-ai-public.js', array('jquery'), $this->version, true);
    }

    public function do_chatx_post_request($url, $data)
    {
        $data['at'] = \Chatx_Ai_Options::read('chatxai_api_token');
        $data['ak'] = \Chatx_Ai_Options::read('chatxai_api_key');

        $options = array(
            'http' => array(
                'header'  => "Content-type: application/x-www-form-urlencoded\r\n",
                'method'  => 'POST',
                'content' => http_build_query($data),
            ),
        );
        $url     = CHATX_BAESURL . '/' . $url;
        $context = stream_context_create($options);
        $result  = file_get_contents($url, false, $context);

        if ($result === false) {
            return false;
        }

        $result_array = null;

        try {
            $result_array = json_decode($result);
        } catch (Exception $e) {

        }

        return $result_array;
    }

    public function set_session_user_ref($campaign = "checbox_form")
    {
        $session_tracker = Session_Tracker_Instance();
        $session_key     = $session_tracker->get_tracking_key();
        $user_identifier = 'checkbox--' . $campaign . '--' . $session_key . '--' . time(true) . '--' . rand(0, 9999);

        return base64_encode($user_identifier);
    }

    public function has_checbox_settings_filled()
    {
        return $this->chatxai_options['mess_app_id'] && $this->chatxai_options['page_id'] && $this->chatxai_options['origin'];
    }

    public function register_shortcodes()
    {
        add_shortcode('messenger_checkbox', [$this, 'messenger_checkbox_shortcode']);
        add_shortcode('send_to_messenger', [$this, 'send_to_messenger_shortcode']);
    }

    public function messenger_checkbox_shortcode($atts)
    {
        $atts = shortcode_atts([
            'campaign'        => 'form_checbox',
            'type'            => 'form',
            'button-selector' => '',
            'parent-selector' => '',
            'template'        => null,
            'bubble'          => '',
            'customcss'       => '',
            'id'              => ''
        ], $atts, 'messenger_checkbox');

        if ($atts['template']) {
            $checkbox_templates = Chatx_Ai_Options::read('chatxai_checkbox_templates', []);

            $foundTemplate = null;
            foreach ($checkbox_templates as $template) {
                $template_id = isset($template['id']) ? $template['id'] : null;

                if ($template_id == $atts['template']) {
                    $foundTemplate = $template;
                }
            }

            if (!$foundTemplate) {
                if ($atts['template'] == "default-add-to-cart-product-page") {
                    $atts['campaign']     = "add_to_cart_form";
                    $checkbox_templates[] = [
                        'id'              => "default-add-to-cart-product-page",
                        'campaign'        => 'add_to_cart_form',
                        'type'            => $atts['type'],
                        'button-selector' => $atts['button-selector'],
                        'bubble'          => '173 customers got amazing discounts by checking this.',
                    ];
                    Chatx_Ai_Options::update('chatxai_checkbox_templates', $checkbox_templates);
                } else if ($atts['template'] == "default-add-to-cart-loop") {
                    $atts['campaign']     = "add_to_cart_form";
                    $checkbox_templates[] = [
                        'id'              => "default-add-to-cart-loop",
                        'campaign'        => 'add_to_cart_form',
                        'type'            => 'button',
                        'button-selector' => '.product a.add_to_cart_button,.product button.add_to_cart_button',
                        'bubble'          => '173 customers got amazing discounts by checking this.',
                    ];
                    Chatx_Ai_Options::update('chatxai_checkbox_templates', $checkbox_templates);
                } else {
                    echo '<span style="color:red;">Invalid checkbox template!</span>';
                    return;
                }
            } else {
                $atts['id']              = isset($foundTemplate['id']) ? $foundTemplate['id'] : '';
                $atts['campaign']        = isset($foundTemplate['campaign']) ? $foundTemplate['campaign'] : '';
                $atts['type']            = isset($foundTemplate['type']) ? $foundTemplate['type'] : '';
                $atts['button-selector'] = isset($foundTemplate['button-selector']) ? $foundTemplate['button-selector'] : '';
                $atts['parent-selector'] = isset($foundTemplate['parent-selector']) ? $foundTemplate['parent-selector'] : '';
                $atts['bubble']          = isset($foundTemplate['bubble']) ? $foundTemplate['bubble'] : '173 customers got amazing discounts by checking this.';
                $atts['customcss']       = isset($foundTemplate['customcss']) ? $foundTemplate['customcss'] : '';
            }
        }

        if ($this->has_checbox_settings_filled()) {
            $mess_app_id = $this->chatxai_options['mess_app_id'];
            $page_id     = $this->chatxai_options['page_id'];
            $origin      = $this->chatxai_options['origin'];
            $user_ref    = $this->set_session_user_ref($atts['campaign']);

            ob_start();
            require __DIR__ . '/partials/checkbox-plugin.php';
            return ob_get_clean();
        }

        return $this->error_formatting('Please fill Messenger info');
    }

    public function send_to_messenger_shortcode($atts)
    {
        $atts = shortcode_atts([
            'campaign' => 'send_to_messenger',
        ], $atts, 'send_to_messenger_shortcode');

        if ($this->has_checbox_settings_filled() && is_user_logged_in()) {
            $mess_app_id = $this->chatxai_options['mess_app_id'];
            $page_id     = $this->chatxai_options['page_id'];
            $ref         = base64_encode($atts['campaign'] . '--' . get_current_user_id());

            ob_start();
            require __DIR__ . '/partials/send-to-messenger-plugin.php';
            return ob_get_clean();
        }

        return $this->error_formatting('Please fill Messenger info');
    }

    public function messenger_checkbox_plugin_login()
    {
        if ($this->login_checkbox_enable) {
            echo do_shortcode('[messenger_checkbox campaign="login_form"]');
        }
    }

    public function messenger_checkbox_plugin_register()
    {
        if ($this->register_checkbox_enable) {
            echo do_shortcode('[messenger_checkbox campaign="register_form"]');
        }
    }

    public function messenger_checkbox_plugin_add_to_cart_product_page()
    {
        if (!$this->addtocart_checkbox_enable) {
            return;
        }

        if (!function_exists('ChatXACT')) {
            return;
        }

        $current_ac = ChatXACT()->get_current_abandoned_cart();
        if ($current_ac) {
            return;
        }

        echo do_shortcode('[messenger_checkbox template="default-add-to-cart-product-page"]');
    }

    public function messenger_checkbox_plugin_add_to_cart_loop()
    {
        if (!$this->addtocart_archive_checkbox_enable) {
            return;
        }

        if (!function_exists('ChatXACT')) {
            return;
        }

        $current_ac = ChatXACT()->get_current_abandoned_cart();
        if ($current_ac) {
            return;
        }

        echo do_shortcode('[messenger_checkbox template="default-add-to-cart-loop"]');
    }

    public function error_formatting($text = '')
    {
        return '<strong>ChatX Error: </strong>' . '<p style="color:red">' . $text . '</p>';
    }

    public function action_upgrade_completed($upgrader_object, $options)
    {
        if ($options['action'] == 'update' && $options['type'] == 'plugin' && isset($options['plugins'])) {
            Chatx_Ai_Options::trigger_changes();
        }
    }
}
